<?php

namespace App\Mail;

use Illuminate\Bus\Queueable;
use Illuminate\Mail\Mailable;
use Illuminate\Mail\Mailables\Content;
use Illuminate\Mail\Mailables\Envelope;
use Illuminate\Queue\SerializesModels;
use Botble\Media\Facades\RvMedia;

class WelcomeEmail extends Mailable
{
    use Queueable, SerializesModels;

    public $type;
    public $site_title = 'TIFR';
    // public $site_url = 'https://example.com';
    public $site_logo;
    public $date_time;
    public $site_url;
    public $site_email = 'tifrsupport@example.com';
    public $site_copyright = 'TIFR © 2024 Your Company';


    /**
     * Create a new message instance.
     */
    public function __construct($type, $date_time = null)
    {

        $this->type = $type;
        $this->date_time = $date_time ?? now();
        $this->site_logo = $this->getPublicSiteLogo();
        $this->site_url = route('public.index');
    }
    public function envelope(): Envelope
    {
        return new Envelope(
            subject: $this->getSubject(),
        );
    }

    public function content(): Content
    {

        return new Content(
            view: 'emails.' . $this->type,
            with: [
                'site_title' => $this->site_title,
                'site_url' => $this->site_url,
                'site_logo' => $this->site_logo,
                'date_time' => $this->date_time,
                'site_email' => $this->site_email,
                'site_copyright' => $this->site_copyright,
            ],
        );
    }

    public function getSubject()
    {
        switch ($this->type) {
            case 'registration_confirmation':
                return 'Faculty Applicant Registration: Please Verify Your Email';
            case 'new_faculty_application':
                return 'New Faculty Application Submitted';
            case 'approval':
                return 'Congratulations, you have been selected';
            case 'rejection':
                return 'Your application has been rejected';
            case 'selection':
                return 'A candidate has been selected';
            default:
                return 'Notification from Our Platform';
        }
    }

    protected function getPublicSiteLogo(): string
    {
        $siteLogo = setting('email_template_logo');
        $siteLogo = apply_filters('core_email_template_site_logo', $siteLogo);

        return $siteLogo
            ? RvMedia::getImageUrl($siteLogo)
            : (
                ($adminLogo = setting('admin_logo'))
                ? RvMedia::getImageUrl($adminLogo)
                : url(config('core.base.general.logo'))
            );
    }

    /**
     * Get the attachments for the message.
     *
     * @return array<int, \Illuminate\Mail\Mailables\Attachment>
     */
    public function attachments(): array
    {
        return [];
    }
}
