<?php

namespace Botble\Blog\Http\Controllers;

use Botble\Base\Http\Actions\DeleteResourceAction;
use Botble\Base\Http\Controllers\BaseController;
use Botble\Base\Http\Responses\BaseHttpResponse;
use Botble\Base\Supports\Breadcrumb;
use Botble\Blog\Forms\PostForm;
use Botble\Blog\Http\Requests\PostRequest;
use Botble\Blog\Models\Post;
use Botble\Blog\Services\StoreCategoryService;
use Botble\Blog\Services\StoreTagService;
use Botble\Blog\Tables\PostTable;
use Illuminate\Http\Request;

class PostController extends BaseController
{
    protected function breadcrumb(): Breadcrumb
    {
        return parent::breadcrumb()
            ->add(trans('plugins/blog::base.menu_name'))
            ->add(trans('plugins/blog::posts.menu_name'), route('posts.index'));
    }

    public function index(PostTable $dataTable)
    {
        $this->pageTitle(trans('plugins/blog::posts.menu_name'));

        return $dataTable->renderTable();
    }

    public function create()
    {
        $this->pageTitle(trans('plugins/blog::posts.create'));

        // return PostForm::create()->renderForm();

        return PostForm::create([
            'files' => true,
        ])->renderForm();
    }

    public function store(
        PostRequest $request,
        StoreTagService $tagService,
        StoreCategoryService $categoryService
    ) {
        $form = PostForm::create()->setRequest($request)->save();

        $post = $form->getModel();

        // echo '<pre>';
        // print_r($_REQUEST);
        // print_r($_FILES);
        // die;

        if ($request->hasFile('pdf_file')) {
            $pdfFile = $request->file('pdf_file');

            if ($pdfFile->isValid()) {

                $fileName = $pdfFile->getClientOriginalName();

                $pdfFile->storeAs('pdf', $pdfFile->getClientOriginalName(), 'public');
                $post->pdf_file = $fileName;
                $post->save();
            }
        }

        $tagService->execute($request, $post);

        $categoryService->execute($request, $post);

        return $this
            ->httpResponse()
            ->setPreviousRoute('posts.index')
            ->setNextRoute('posts.edit', $post->getKey())
            ->withCreatedSuccessMessage();
    }

    public function edit(Post $post)
    {
        $this->pageTitle(trans('core/base::forms.edit_item', ['name' => $post->name]));

        // return PostForm::createFromModel($post)->renderForm();

        return PostForm::createFromModel($post, [
            'files' => true,
        ])->renderForm();
    }

    public function update(
        Post $post,
        PostRequest $request,
        StoreTagService $tagService,
        StoreCategoryService $categoryService,
    ) {
        $form = PostForm::createFromModel($post)
            ->setRequest($request)
            ->save();

        $post = $form->getModel();

        if ($request->has('remove_pdf_file') && $request->get('remove_pdf_file') == '1') {

            if ($post->pdf_file && file_exists(public_path('storage/pdf/' . $post->pdf_file))) {
                unlink(public_path('storage/pdf/' . $post->pdf_file));  // Remove the old PDF file
            }

            $post->pdf_file = null;
            $post->save();
        }

        if ($request->hasFile('pdf_file')) {
            $pdfFile = $request->file('pdf_file');

            if ($pdfFile->isValid()) {
                $fileName = $pdfFile->getClientOriginalName();

                if ($post->pdf_file && file_exists(public_path('storage/pdf/' . $post->pdf_file))) {
                    unlink(public_path('storage/pdf/' . $post->pdf_file));
                }

                $pdfFile->storeAs('pdf', $pdfFile->getClientOriginalName(), 'public');
                $post->pdf_file = $fileName;
                $post->save();
            }
        }

        $tagService->execute($request, $post);

        $categoryService->execute($request, $post);

        return $this
            ->httpResponse()
            ->setPreviousRoute('posts.index')
            ->withUpdatedSuccessMessage();
    }

    public function destroy(Post $post): DeleteResourceAction
    {
        return DeleteResourceAction::make($post);
    }

    public function getWidgetRecentPosts(Request $request): BaseHttpResponse
    {
        $limit = $request->integer('paginate', 10);
        $limit = $limit > 0 ? $limit : 10;

        $posts = Post::query()
            ->with(['slugable'])
            ->orderByDesc('created_at')
            ->limit($limit)
            ->get();

        return $this
            ->httpResponse()
            ->setData(view('plugins/blog::widgets.posts', compact('posts', 'limit'))->render());
    }
}
