<?php

namespace Botble\TifrFacultyRecruitmentApplication\Tables;

use Botble\Table\Abstracts\TableAbstract;
use Botble\Table\Actions\EditAction;
use Botble\Table\Columns\CreatedAtColumn;
use Botble\Table\Columns\IdColumn;
use Botble\Table\Columns\NameColumn;
use Botble\Table\Columns\Column;
use Illuminate\Database\Eloquent\Builder;

class TifrFacultyRecruitmentApplicationTable extends TableAbstract
{
    public function setup(): void
    {
        $this
            ->addActions([
                EditAction::make()->route('tifrfacultyrecruitmentapplication.edit'),

                \Botble\Table\Actions\Action::make('view')
                    ->label('View Evaluations')
                    ->color('primary')
                    ->route('tifrfacultyrecruitmentapplication.committee.recommendations', ['id' => '{id}'])
                    ->attributes(['target' => '_blank'])
                    ->icon('ti ti-eye'),
            ])
            ->addColumns([
                IdColumn::make(),
                NameColumn::make('full_name')->label('Full Name')->route('tifrfacultyrecruitmentapplication.edit'),
                Column::make('gender')->label('Gender'),
                Column::make('email')->label('Email'),
                Column::make('phone')->label('Phone'),
                Column::make('evaluation_status')->label('Evaluation'),
                Column::make('evaluation_details')->label('Evaluation Details'),
                CreatedAtColumn::make(),
            ])
            ->queryUsing(function (Builder $query) {
                // $logged_in_user_id = auth()->id();
                $userRole = auth()->user()->roles()->first()->name;
                // $userRole = Role::first()->name;

                if ($userRole == 'Committee Member' || $userRole == 'Chairperson') {
                    $query->from('tifr_faculty_registrations')
                        ->leftJoin('tifr_faculty_registration_evaluation_statuses', 'tifr_faculty_registrations.id', '=', 'tifr_faculty_registration_evaluation_statuses.faculty_recruitment_application_id')
                        ->leftJoin('tifr_faculty_registration_evaluations', 'tifr_faculty_registrations.id', '=', 'tifr_faculty_registration_evaluations.faculty_recruitment_application_id')
                        ->select([
                            'tifr_faculty_registrations.id',
                            \DB::raw('CONCAT(tifr_faculty_registrations.first_name, " ", IFNULL(tifr_faculty_registrations.middle_name, ""), " ", tifr_faculty_registrations.last_name) AS full_name'),
                            'tifr_faculty_registrations.gender',
                            'tifr_faculty_registrations.email',
                            'tifr_faculty_registrations.phone',
                            \DB::raw('
                                CASE 
                                    WHEN tifr_faculty_registration_evaluation_statuses.is_complete IS NULL OR tifr_faculty_registration_evaluation_statuses.is_complete != "Yes" THEN "Pending"
                                    ELSE "Done"
                                END AS evaluation_status
                            '),
                            'tifr_faculty_registrations.id',
                            'tifr_faculty_registration_evaluation_statuses.is_complete',
                            'tifr_faculty_registrations.created_at',

                            //     \DB::raw('COALESCE(CONCAT(
                            //     "Grade - ", tifr_faculty_registration_evaluations.grade, "<br>",
                            //     "Recommendation - ", tifr_faculty_registration_evaluations.recommendation, "<br>",
                            //     "Comment - ", tifr_faculty_registration_evaluations.comments
                            // ), "-") AS evaluation_details')

                            //     \DB::raw('COALESCE(CONCAT(
                            //     "Grade - ", tifr_faculty_registration_evaluations.grade, "<br>",
                            //     "Recommendation - ", tifr_faculty_registration_evaluations.recommendation, "<br>",
                            //     "Comment - ", tifr_faculty_registration_evaluations.comments
                            // ), "-") AS evaluation_details')

                            \DB::raw('COALESCE(CONCAT(
                                "Grade - ", tifr_faculty_registration_evaluations.grade, "<br>",
                                "Recommendation - ", tifr_faculty_registration_evaluations.recommendation, "<br>",
                                "Comment - ", 
                                IFNULL(
                                    CONCAT(
                                        "<i class=\"fa-solid fa-circle-info\" style=\"cursor: pointer; color: #007bff; font-weight: bold; font-size: 16px;\" title=\"", tifr_faculty_registration_evaluations.comments, "\"></i>"),
                                    "-")
                            ), "-") AS evaluation_details')
                        ]);
                } else {
                    $query->from('tifr_faculty_registrations')
                        ->whereRaw('1 = 0'); // This ensures no records are returned by the query
                }
            });
    }

    // public function getRowActions(): array
    // {
    //     $actions = parent::getRowActions();

    //     foreach ($actions as $key => $action) {
    //         if ($key === 'view' && $this->evaluation_status !== 'Done') {
    //             unset($actions[$key]); // Remove the 'view' action if evaluation status is not 'Done'
    //         }
    //     }

    //     return $actions;
    // }

    public function getRowActions(): array
    {
        $actions = parent::getRowActions();

        // Manually fetch data using the same query as in queryUsing()
        $userRole = auth()->user()->roles()->first()->name;

        if ($userRole == 'Committee Member' || $userRole == 'Chairperson') {
            $data = \DB::table('tifr_faculty_registrations')
                ->leftJoin('tifr_faculty_registration_evaluation_statuses', 'tifr_faculty_registrations.id', '=', 'tifr_faculty_registration_evaluation_statuses.faculty_recruitment_application_id')
                ->leftJoin('tifr_faculty_registration_evaluations', 'tifr_faculty_registrations.id', '=', 'tifr_faculty_registration_evaluations.faculty_recruitment_application_id')
                ->select([
                    'tifr_faculty_registrations.id',
                    \DB::raw('CONCAT(tifr_faculty_registrations.first_name, " ", IFNULL(tifr_faculty_registrations.middle_name, ""), " ", tifr_faculty_registrations.last_name) AS full_name'),
                    'tifr_faculty_registrations.gender',
                    'tifr_faculty_registrations.email',
                    'tifr_faculty_registrations.phone',
                    \DB::raw('
                    CASE 
                        WHEN tifr_faculty_registration_evaluation_statuses.is_complete IS NULL OR tifr_faculty_registration_evaluation_statuses.is_complete != "Yes" THEN "Pending"
                        ELSE "Done"
                    END AS evaluation_status
                '),
                    'tifr_faculty_registrations.id',
                    'tifr_faculty_registration_evaluation_statuses.is_complete',
                    'tifr_faculty_registrations.created_at',
                    \DB::raw('COALESCE(CONCAT(
                    "Grade - ", tifr_faculty_registration_evaluations.grade, "<br>",
                    "Recommendation - ", tifr_faculty_registration_evaluations.recommendation, "<br>",
                    "Comment - ", 
                    IFNULL(
                        CONCAT(
                            "<i class=\"fa-solid fa-circle-info\" style=\"cursor: pointer; color: #007bff; font-weight: bold; font-size: 16px;\" title=\"", tifr_faculty_registration_evaluations.comments, "\"></i>"),
                        "-")
                ), "-") AS evaluation_details')
                ])
                ->get();  // Execute the query and get results

            // Check if there is data
            if ($data->isNotEmpty()) {
                // Iterate through each row and check the evaluation status and show/hide view button
                foreach ($data as $row) {
                    $evaluationStatus = $row->evaluation_status;
                    if ($evaluationStatus !== 'Done') {
                        foreach ($actions as $key => $action) {
                            if ($key === 'view') {
                                unset($actions[$key]);
                            }
                        }
                    }
                }
            }
        } else {
            // In case of no matching role, remove actions or handle accordingly
            $actions = [];
        }

        return $actions;
    }
}
