<?php

namespace Botble\TifrFacultyRecruitmentApplication\Tables;

use Botble\Table\Abstracts\TableAbstract;
use Botble\Table\Actions\EditAction;
use Botble\Table\Columns\CreatedAtColumn;
use Botble\Table\Columns\IdColumn;
use Botble\Table\Columns\NameColumn;
use Botble\Table\Columns\Column;
use Illuminate\Database\Eloquent\Builder;

class TifrFacultyRecruitmentApplicationTable extends TableAbstract
{
    public function setup(): void
    {
        $this
            ->addActions([
                EditAction::make()->route('tifrfacultyrecruitmentapplication.edit'),
            ])
            ->addColumns([
                IdColumn::make(),
                NameColumn::make('full_name')->label('Full Name')->route('tifrfacultyrecruitmentapplication.edit'),
                Column::make('gender')->label('Gender'),
                Column::make('email')->label('Email'),
                Column::make('phone')->label('Phone'),
                Column::make('evaluation_status')->label('Evaluation'),
                Column::make('evaluation_details')->label('Evaluation Details'),
                Column::make('all_evaluation_details_btn')->label('All Evaluations'),
                CreatedAtColumn::make(),
            ])
            ->queryUsing(function (Builder $query) {

                $baseUrl = url('/');
                $userRole = auth()->user()->roles()->first()->name;
                $userId = auth()->id();

                if ($userRole == 'Committee Member' || $userRole == 'Chairperson') {
                    $query->from('tifr_faculty_registrations')
                        ->leftJoin('tifr_faculty_registration_evaluation_statuses', 'tifr_faculty_registrations.id', '=', 'tifr_faculty_registration_evaluation_statuses.faculty_recruitment_application_id')
                        ->leftJoin('tifr_faculty_registration_evaluations', function ($join) use ($userId) {
                            // Join only the evaluations for the logged-in evaluator
                            $join->on('tifr_faculty_registrations.id', '=', 'tifr_faculty_registration_evaluations.faculty_recruitment_application_id')
                                ->where('tifr_faculty_registration_evaluations.evaluator_id', '=', $userId);  // Filter for the current evaluator
                        })
                        ->select([
                            'tifr_faculty_registrations.id',
                            \DB::raw('CONCAT(tifr_faculty_registrations.first_name, " ", IFNULL(tifr_faculty_registrations.middle_name, ""), " ", tifr_faculty_registrations.last_name) AS full_name'),
                            'tifr_faculty_registrations.gender',
                            'tifr_faculty_registrations.email',
                            'tifr_faculty_registrations.phone',

                            // Evaluation status: check if the logged-in user has evaluated this application
                            \DB::raw('
                            CASE 
                                WHEN EXISTS (
                                    SELECT 1
                                    FROM tifr_faculty_registration_evaluations
                                    WHERE faculty_recruitment_application_id = tifr_faculty_registrations.id
                                    AND evaluator_id = ' . $userId . '
                                ) THEN "Done"
                                ELSE "Pending"
                            END AS evaluation_status
                            '),

                            'tifr_faculty_registrations.created_at',

                            // Evaluation details based on the logged-in evaluator's evaluation
                            \DB::raw(
                                'COALESCE(
                                CASE 
                                    WHEN tifr_faculty_registration_evaluations.recommendation IS NOT NULL THEN 
                                        CONCAT(
                                            "Grade - ", tifr_faculty_registration_evaluations.grade, "<br>",
                                            "Recommendation - ", tifr_faculty_registration_evaluations.recommendation, "<br>",
                                            "Comment - ", 
                                            IFNULL(
                                                CONCAT(
                                                    "<i class=\"fa-solid fa-circle-info\" style=\"cursor: pointer; color: #007bff; font-weight: bold; font-size: 16px;\" title=\"", tifr_faculty_registration_evaluations.comments, "\"></i>"),
                                                "-")
                                        )
                                    ELSE 
                                        "-"
                                END, 
                                "-") AS evaluation_details'
                            ),

                            'tifr_faculty_registrations.phone AS evaluation_details111',

                            // \DB::raw('
                            //     CONCAT(
                            //         "<a href=\"/tifrfacultyrecruitmentapplication/committee/recommendations/", 
                            //         tifr_faculty_registrations.id, 
                            //         "\" class=\"btn btn-primary\">View</a>"
                            //     ) AS all_evaluation_details_btn
                            // ')

                            \DB::raw('
                            CASE 
                                WHEN tifr_faculty_registration_evaluation_statuses.is_complete = "Yes" THEN 
                                    CONCAT(
                                        "<a href=\"' . $baseUrl . '/admin/tifrfacultyrecruitmentapplications/committee/recommendations/", 
                                        tifr_faculty_registrations.id, 
                                        "\" class=\"btn btn-primary btn-sm\" target=\"_blank\">View</a>"
                                    )
                                ELSE 
                                    "-"
                            END AS all_evaluation_details_btn
                        ')



                        ])
                        // Ensure we only show applications that belong to the evaluator
                        ->where(function ($query) use ($userId) {
                            $query->whereNull('tifr_faculty_registration_evaluations.recommendation')  // Pending evaluation (NULL recommendation)
                                ->orWhereNotNull('tifr_faculty_registration_evaluations.recommendation') // Evaluated (not NULL)
                                ->orWhere(function ($subQuery) use ($userId) {
                                    $subQuery->where('tifr_faculty_registration_evaluations.evaluator_id', $userId) // Evaluator is the logged-in user
                                        ->orWhereNull('tifr_faculty_registration_evaluations.evaluator_id'); // Or no evaluation exists yet (NULL evaluator_id)
                                });
                        });
                } else {
                    // No data is returned for other roles
                    $query->from('tifr_faculty_registrations')
                        ->whereRaw('1 = 0');
                }
            });
    }
}
