<?php

namespace Botble\TifrTeamMaster\Http\Controllers;

use Botble\Base\Http\Actions\DeleteResourceAction;
use Botble\TifrTeamMaster\Models\TifrTeamMaster;
use Botble\TifrTeamMaster\Models\TifrTeamCategory;
use Botble\Base\Http\Controllers\BaseController;
use Botble\TifrTeamMaster\Tables\TifrTeamMasterTable;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Botble\Base\Http\Responses\BaseHttpResponse;

class TifrTeamMasterController extends BaseController
{
    public function __construct()
    {
        $this
            ->breadcrumb()
            ->add(trans(trans('plugins/tifrteammaster::tifrteammaster.name')), route('tifrteammaster.index'));
    }

    public function index(TifrTeamMasterTable $table)
    {
        $this->pageTitle(trans('plugins/tifrteammaster::tifrteammaster.name'));

        return $table->renderTable();
    }

    public function create()
    {
        $this->pageTitle('New Team Member');
        $mainCategories = TifrTeamCategory::where('parent_category_id', 0)
            ->pluck('name', 'id')
            ->toArray();

        return view('tifrteammaster::tifrteammaster.tifr_team_master_form', compact('mainCategories'));
    }

    public function store(Request $request, BaseHttpResponse $response)
    {
        $data = $request->all();

        $tifrTeamMaster = new TifrTeamMaster();

        if ($request->hasFile('profile_picture')) {
            $file = $request->file('profile_picture');
            $extension = $file->getClientOriginalExtension();
            $fullName = $request->input('full_name');

            $fileName = strtolower(str_replace(' ', '_', $fullName)) . '.' . $extension;

            $file->storeAs('tifr_team_member_profile_pictures', $fileName, 'public');

            $data['profile_picture'] = $fileName;
        }

        $tifrTeamMaster->fill($data)->save();

        return $response
            ->setPreviousUrl(route('tifrteammaster.index'))
            ->setMessage(trans('core/base::notices.create_success_message'));
    }


    public function edit($id)
    {
        $tifrTeamMaster = TifrTeamMaster::findOrFail($id);

        $this->pageTitle(trans('core/base::forms.edit_item', ['name' => $tifrTeamMaster->full_name]));

        $mainCategories = TifrTeamCategory::where('parent_category_id', 0)
            ->pluck('name', 'id')
            ->toArray();

        $subCategories = TifrTeamCategory::where('parent_category_id', $tifrTeamMaster->main_category_id)
            ->pluck('name', 'id')
            ->toArray();

        return view('tifrteammaster::tifrteammaster.tifr_team_master_form', compact(
            'tifrTeamMaster',
            'mainCategories',
            'subCategories'
        ));
    }

    public function update(Request $request, $id, BaseHttpResponse $response)
    {

        $data = $request->all();

        $tifrTeamMaster = TifrTeamMaster::findOrFail($id);

        if ($request->input('hidden_delete_profile_picture') == '1') {
            if ($tifrTeamMaster->profile_picture) {
                Storage::disk('public')->delete($tifrTeamMaster->profile_picture);
            }

            $data['profile_picture'] = null;
        }

        if ($request->hasFile('profile_picture')) {
            if ($tifrTeamMaster->profile_picture) {
                Storage::disk('public')->delete($tifrTeamMaster->profile_picture);
            }

            $fullName = $request->input('full_name');

            $extension = $request->file('profile_picture')->getClientOriginalExtension();

            $fileName = strtolower(str_replace(' ', '_', $fullName)) . '.' . $extension;

            $request->file('profile_picture')
                ->storeAs('tifr_team_member_profile_pictures', $fileName, 'public');

            $data['profile_picture'] = $fileName;
        }

        $tifrTeamMaster->fill($data)->save();

        return $response
            ->setPreviousUrl(route('tifrteammaster.index'))
            ->setMessage(trans('core/base::notices.update_success_message'));
    }


    public function destroy($id)
    {
        $tifrTeamMaster = TifrTeamMaster::find($id);
        return DeleteResourceAction::make($tifrTeamMaster);
    }

    public function getSubCategories(Request $request)
    {
        if ($request->has('main_category_id') && $request->input('main_category_id')) {
            $mainCategoryId = $request->input('main_category_id');

            $subCategories = TifrTeamCategory::where('parent_category_id', $mainCategoryId)
                ->pluck('name', 'id');

            if ($subCategories->isNotEmpty()) {

                return response()->json([
                    'status' => 'success',
                    'data' => $subCategories
                ]);
            } else {

                return response()->json([
                    'status' => 'error',
                    'message' => 'No sub-categories available'
                ]);
            }
        } else {

            return response()->json([
                'status' => 'error',
                'message' => 'Main category ID is missing or invalid'
            ]);
        }
    }
}
