<?php

namespace Botble\TifrTeamMaster\Tables;

use Botble\TifrTeamMaster\Models\TifrTeamMaster;
use Botble\Table\Abstracts\TableAbstract;
use Botble\Table\Actions\DeleteAction;
use Botble\Table\Actions\EditAction;
use Botble\Table\BulkActions\DeleteBulkAction;
use Botble\Table\Columns\CreatedAtColumn;
use Botble\Table\Columns\IdColumn;
use Botble\Table\Columns\NameColumn;
use Botble\Table\Columns\Column;
use Botble\Table\HeaderActions\CreateHeaderAction;
use Illuminate\Database\Eloquent\Builder;

class TifrTeamMasterTable extends TableAbstract
{
    public function setup(): void
    {
        $this
            ->model(TifrTeamMaster::class)
            ->addHeaderAction(CreateHeaderAction::make()->route('tifrteammaster.create'))
            ->addActions([
                EditAction::make()->route('tifrteammaster.edit'),
                DeleteAction::make()->route('tifrteammaster.destroy'),
            ])
            ->addColumns([
                IdColumn::make(),
                NameColumn::make('full_name')->label('Full Name')->route('tifrteammaster.edit'),
                Column::make('email')->label('Email'),
                Column::make('mobile')->label('Mobile'),
                CreatedAtColumn::make(),
                Column::make('status')->label('Status'),
                // Column::make('category_name')->label('Category'),
                // Column::make('subcategory_name')->label('Subcategory'),
            ])
            ->addBulkActions([
                DeleteBulkAction::make()->permission('tifrteammaster.destroy'),
            ])
            // ->addFilters([
            //     Column::make('full_name')
            //         ->label('Full Name')
            //         ->filterable()
            //         ->sortable(),
            //     Column::make('status')
            //         ->label('Status')
            //         ->filterable()
            //         ->sortable(),
            //     Column::make('email')
            //         ->label('Email')
            //         ->filterable()
            //         ->sortable(),
            //     Column::make('mobile')
            //         ->label('Mobile')
            //         ->filterable()
            //         ->sortable(),
            // ])
            ->queryUsing(function (Builder $query) {
                $query->select([
                    'id',
                    'full_name',
                    'email',
                    'mobile',
                    'created_at',
                    'status',
                ]);
            });
        // ->queryUsing(function (Builder $query) {
        //     $query->select([
        //         'ttm.id',
        //         'ttm.full_name',
        //         'ttm.email',
        //         'ttm.mobile',
        //         'ttm.created_at',
        //         'ttm.status',
        //         'ttm.main_category_id',
        //         'ttm.sub_category_id',
        //         'mc.name as category_name',
        //         'sc.name as subcategory_name',
        //     ])
        //         ->leftJoin('tifr_team_categories as mc', 'ttm.main_category_id', '=', 'mc.id')
        //         ->leftJoin('tifr_team_categories as sc', 'ttm.sub_category_id', '=', 'sc.id');
        // });
    }
}
