<?php

namespace Theme\Tifr\Http\Controllers;

use Botble\Theme\Http\Controllers\PublicController;
use Botble\Blog\Models\Post;
use Botble\Blog\Models\Category;
use Botble\Slug\Facades\SlugHelper;
use Illuminate\Http\Request;
use Theme;

class TifrController extends PublicController
{
    public function getIndex()
    {
        return parent::getIndex();
    }

    public function getView(?string $key = null, string $prefix = '')
    {
        return parent::getView($key);
    }

    public function getSiteMapIndex(string $key = null, string $extension = 'xml')
    {
        return parent::getSiteMapIndex();
    }

    public function getCalendarSearch(Request $request)
    {
        // Retrieve the 'calendar' category by slug using SlugHelper
        $slug = SlugHelper::getSlug('calendar');
        $category = null;

        // Check if the slug exists
        if ($slug && $slug->reference_type == Category::class) {
            $category = Category::find($slug->reference_id);
        }

        // If the category exists
        if ($category) {

            $query = Post::query();

            $query->whereHas('categories', function ($query) use ($category) {
                $query->where('categories.id', $category->id);
            });

            if ($request->has('search') && $request->input('search') != '') {
                $query->where(function ($query) use ($request) {
                    $query->where('name', 'like', '%' . $request->input('search') . '%')
                        ->orWhere('description', 'like', '%' . $request->input('search') . '%');
                });
            }

            if ($request->has('year') && $request->input('year') != '') {
                $query->whereYear('created_at', $request->input('year'));
            }

            $query->where('status', 'published');
            $query->orderBy('id', 'desc');

            $posts = $query->paginate(10);

            return Theme::uses('tifr')->scope('category', compact('posts', 'category', 'request'))->render();
        }

        // If the category isn't found, return an empty result
        return Theme::uses('tifr')->scope('category', ['posts' => collect(), 'category' => null, 'request' => $request])->render();
    }

    public function getGlobalSearch(Request $request)
    {

        $query = $request->input('q');
        $queryBuilder = Post::query();

        if ($query) {
            $queryBuilder->where(function ($queryBuilder) use ($query) {
                $queryBuilder->where('name', 'like', '%' . $query . '%')
                    ->orWhere('description', 'like', '%' . $query . '%');
            });
        }

        $queryBuilder->where('status', 'published');
        $queryBuilder->orderBy('id', 'desc');

        $posts = $queryBuilder->paginate(10);

        return Theme::uses('tifr')->scope('search', compact('posts', 'query'))->render();
    }

    public function getFacultyDetail($id)
    {
        $faculty = \DB::table('tifr_team_masters')
            ->where('id', $id)
            ->first();

        $other_faculty = \DB::table('tifr_team_masters')
            ->where('id', '!=', $id)
            ->where('main_category_id', $faculty->main_category_id)
            ->where('sub_category_id', $faculty->sub_category_id)
            ->get();
        return Theme::uses('tifr')->scope('faculty.faculty-detail', compact('faculty', 'other_faculty'))->render();
    }

    public function getNewsSearch(Request $request)
    {
        $slug = SlugHelper::getSlug('news-events');
        $category = null;

        if ($slug && $slug->reference_type == Category::class) {
            $category = Category::find($slug->reference_id);
        }

        if ($category) {
            $query = Post::query();
            $query->whereHas('categories', function ($query) use ($category) {
                $query->where('categories.id', $category->id);
            });

            if ($request->has('search') && $request->input('search') != '') {
                $query->where(function ($query) use ($request) {
                    $query->where('name', 'like', '%' . $request->input('search') . '%')
                        ->orWhere('description', 'like', '%' . $request->input('search') . '%');
                });
            }

            $query->where('status', 'published');
            $query->orderBy('id', 'desc');

            $posts = $query->paginate(10);
            return Theme::uses('tifr')->scope('category', compact('posts', 'category', 'request'))->render();
        }

        return Theme::uses('tifr')->scope('category', ['posts' => collect(), 'category' => null, 'request' => $request])->render();
    }
}
